@@ -7,10 +7,30 @@ Created on 4 Sep 2020
 
 import os, config_path
 
+PRODUCTION_MODE                                     = "PROD"
+DEMO_MODE                                           = "DEMO"
+LOCAL_MODE                                          = "LOCAL"
+
+DEPLOYMENT_MODE                                     = os.environ.get('DEPLOYMENT_MODE')
 
 SECRET_KEY                                          = os.environ.get('SECRET_KEY')
 MAX_PASSWORD_LENGTH                                 = os.environ.get('MAX_PASSWORD_LENGTH')
 
+SYSTEM_TASK_GCLOUD_PROJECT_ID                       = os.environ.get('SYSTEM_TASK_GCLOUD_PROJECT_ID')
+SYSTEM_TASK_GCLOUD_LOCATION                         = os.environ.get('SYSTEM_TASK_GCLOUD_LOCATION')
+SYSTEM_TASK_SERVICE_ACCOUNT_KEY_FILEPATH            = os.environ.get('SYSTEM_TASK_SERVICE_ACCOUNT_KEY')
+SYSTEM_TASK_SERVICE_CREDENTIAL_PATH                 = os.path.abspath(os.path.dirname(config_path.__file__)) + '/' + SYSTEM_TASK_SERVICE_ACCOUNT_KEY_FILEPATH
+SYSTEM_TASK_SERVICE_ACCOUNT_EMAIL                   = os.environ.get('SYSTEM_TASK_SERVICE_ACCOUNT_EMAIL')
+
+SYSTEM_BASE_URL                                     = os.environ.get('SYSTEM_BASE_URL')
+
+def task_url(path):
+    return '{}{}'.format(SYSTEM_BASE_URL, path)
+
+CHECK_CUSTOMER_ENTITLE_REWARD_TASK_URL              = task_url('/rewarding/check-entitle-reward')
+SEND_EMAIL_TASK_URL                                 = task_url('/system/send-email')
+
+
 #SENDGRID_API_KEY                                    = os.environ.get('SENDGRID_API_KEY')
 
 
